<div class="base">
<img class='barcode' src='{{label_tools.barcode(barcode, module_width=2, font_size=30)}}' />
<span id="name">{{ full_name }}</span>
<span id="count">{{ items_count }}</span>
<span  id="total">{{ total }}</span>
  </div>