<div class="base">
  <p class="top-line">{{ sender }}</p>
  <p class="address">
    {{ full_name }} <br/>
    {{ second_address_row }} <br/>
    {{ street }} {{ housenumber }} <br/>
    {{ plz }} {{ place }}
  </p>
</div>