# Generated by Django 3.1.3 on 2020-12-18 13:49

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('order', '0004_order_notes'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='order',
            options={'permissions': [('manage_orders', 'Can manage orders')], 'verbose_name': 'Reihenfolge', 'verbose_name_plural': 'Orders'},
        ),
    ]
