@page {
    width: 100mm;
    height: 62mm;
}
body, .base {
    font-family: sans-serif;
    height: 62mm;
    width: 100mm;

    position: relative;
    margin: 5mm;
}

.top-line {
    width: 90mm;
    border-bottom: 1px solid;
    font-size: 8pt;
    padding-bottom: 1mm;
}
.address {
    font-size: 16pt;
}