body {
    line-height: 1.5;
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
    font-weight: normal;
    color: rgba(0, 0, 0, 0.87);
    display: flex;
    justify-content: center;
    align-items: center;
}

table, tr {
    width: 100%;
}

main {
    max-width: 700px;
    box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.12), 0 1px 5px 0 rgba(0, 0, 0, 0.2);
    -webkit-box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.12), 0 1px 5px 0 rgba(0, 0, 0, 0.2);
    -webkit-transition: -webkit-box-shadow .25s;
    transition: -webkit-box-shadow .25s;
    transition: box-shadow .25s;
    transition: box-shadow .25s, -webkit-box-shadow .25s;
    padding: 24px;
    margin: .5rem 0 1rem 0;
    border-radius: 2px;
    background-color: #fff;
    margin: 30px;
    padding: 20px;
}

.first th {
    border-bottom: 1px solid;
}

.sum-row th, .sum-row td {
    border-top: 1px solid;
}

td, th {
    padding-left: 5px;
    padding-right: 5px;
}

.align-center {
    text-align: center;
}