# Generated by Django 3.1.3 on 2020-12-18 13:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('order', '0005_auto_20201218_1449'),
    ]

    operations = [
        migrations.AddField(
            model_name='orderform',
            name='access_code',
            field=models.CharField(blank=True, max_length=2555, verbose_name='Access code'),
        ),
    ]
