@page {
    width: 54mm;
    height: 17mm;
}
body, .base {
    font-family: sans-serif;
    height: 17mm;
    width: 54mm;

    position: relative;
}
img {
    height: 10mm;
    margin-top: 1mm;
    margin-left: 4mm;
    display: inline-block;
    vertical-align: middle;

    image-rendering: pixelated;
}
#count {
    position: absolute;
    top: 2mm;
    right: 4mm;
}
#name {
    position: absolute;
    left: 4mm;
    bottom: 1mm;
    font-size: 13px;
}
#total {
    position: absolute;
    bottom: 5mm;
    right: 4mm;
}