{% extends 'core/base.html' %}
{% load i18n material_form %}

{% block page_title %}
  {{ object.title }}
{% endblock %}
{% block browser_title %}
  {{ object.title }}
{% endblock %}

{% block content %}
  <div class="container">
    {% include "order/breadcrumbs.html" with step=4 %}

    <h3>
      <i class="material-icons left green-text medium iconify" data-icon="mdi:checkbox-marked-circle-outline"></i>
      {% trans "Thank you!" %}</h3>

    <p class="flow-text">
      {% blocktrans %}
        Your order was submitted successfully. Please check your emails and
        <strong>confirm your order by clicking the link sent to you.</strong>
      {% endblocktrans %}
    </p>

    {{ object.help_text|safe }}
  </div>
{% endblock %}
