{% extends 'core/base.html' %}
{% load i18n material_form %}

{% block page_title %}
  {{ object.title }}
{% endblock %}
{% block browser_title %}
  {{ object.title }}
{% endblock %}

{% block content %}
  <div class="container">
    <p class="flow-text">
      {% blocktrans %}
        Please enter the access code to open this order form:
      {% endblocktrans %}
    </p>

    <form action="" method="post">
      {% csrf_token %}
      {% form form=access_form %}{% endform %}
      <p>
        <button type="submit" class="btn waves-effect waves-light green">
          {% trans "Open form" %}
          <i class="material-icons right iconify" data-icon="mdi:chevron-right"></i>
        </button>
      </p>
    </form>

    {{ object.help_text|safe }}
  </div>
{% endblock %}
