{% extends 'core/base.html' %}
{% load i18n material_form %}

{% block page_title %}
  {{ object.title }}
{% endblock %}
{% block browser_title %}
  {{ object.title }}
{% endblock %}

{% block content %}
  <h3>
    <i class="material-icons left green-text medium iconify" data-icon="mdi:checkbox-marked-circle-outline"></i>
    {% trans "Your order has been confirmed!" %}</h3>

  <p class="flow-text">
    {% blocktrans %}
      Your order has been confirmed successfully. Please check your emails to get information about the further
      process.
    {% endblocktrans %}
  </p>

  {{ object.help_text|safe }}
{% endblock %}
